@@ -12,9 +12,33 @@ from gdcmdtools.auth import GDAuth
 import requests
 import re
 import os
+import json
 
 import pprint
 
+export_format = {
+    "application/vnd.google-apps.spreadsheet":["pdf", "ods", "xlsx"],
+    "application/vnd.google-apps.document":["pdf", "docx", "rtf", "odt", "html", "txt"],    
+    "application/vnd.google-apps.presentation":["pdf", "pptx", "txt"],
+    "application/vnd.google-apps.drawing":["png", "pdf", "jpeg", "svg"],
+    "application/vnd.google-apps.script+json":["js"],
+    }
+
+""" application/vnd.google-apps.script+json
+{  
+    "files": [  
+        {  
+            "id": "bbda34aa-c700-48d9-88bd-ad2573a0620a",  
+            "name": "Code",  
+            "source": "FILE CONTENT",
+            "type": "server_js"
+        }
+    ]
+}
+
+
+"""
+
 class GDGet:
     def __init__(self, file_id, format, save_as):
         # base
@@ -36,6 +60,39 @@ class GDGet:
         else:
             self.save_as = os.path.abspath(save_as)
  
+    def parse_gas_json(self, file_content, save_as):
+        map_type_ext = {"server_js":"js", "html":"html"}
+        try:
+            jsons = json.loads(file_content)
+            new_json = {"files":[]}
+            for j in jsons["files"]:
+                file_id = j["id"]
+                file_name = j["name"]
+                file_source = j["source"]
+                file_type = j["type"]
+
+                if file_type in map_type_ext.keys():
+                    file_ext = map_type_ext[file_type]
+                else:
+                    file_ext = file_type
+
+                file_fullname = "%s.%s" % (file_name, file_ext) 
+
+                with open(file_fullname, 'wb+') as f:
+                    f.write(file_source)
+                
+                j.pop("source")
+                new_json["files"].append(j)
+
+            # save the project id, we need the id to upload project
+            new_json["id"] = self.file_id
+            with open(save_as, 'wb+') as f:
+                f.write(json.dumps(new_json, indent=4))
+
+        except Exception, e:  
+            logger.error(e)
+            raise
+
     def run(self):
         try: 
             service_response = self.get()
@@ -55,8 +112,11 @@ class GDGet:
             if self.save_as == None:
                self.save_as = title 
 
-            with open(self.save_as, 'wb+') as f:
-                f.write(file_content)
+            if self.format == "json":
+                self.parse_gas_json(file_content, self.save_as)               
+            else:
+                with open(self.save_as, 'wb+') as f:
+                    f.write(file_content)
 
         except Exception, e:
             logger.error(e)
@@ -82,6 +142,10 @@ class GDGet:
 
         title = service_response.get('title',None)
 
+        
+        logger.debug(title)
+        logger.debug(export_links)
+
         if export_links == None:
             download_link = service_response.get(u'downloadUrl', None)
             return_format["raw"] = download_link
@@ -90,7 +154,7 @@ class GDGet:
 
             if len(export_link_values) > 0 :
                 for link in export_link_values:
-                    m = re.match(r'^.*exportFormat=(.*)$',link)
+                    m = re.match(r'^.*[Ff]ormat=(.*)$',link)
                     return_format[m.group(1)] = link
 
         return title, return_format
